@@ -1,9 +1,9 @@
 #!/bin/bash
 
 ( cd etc/bootsplash/themes ; rm -rf current )
-( cd etc/bootsplash/themes ; ln -sf vl71/ current )
+( cd etc/bootsplash/themes ; ln -sf VL-Seven/ current )
 ( cd boot/bitmap ; rm -rf boot.bmp )
-( cd boot/bitmap ; ln -sf VL-Rayz.bmp boot.bmp )
+( cd boot/bitmap ; ln -sf VL-Seven.bmp boot.bmp )
 echo "Enjoy The Theme"
 
 ( cd usr/share/icons/Faenza/apps/16 ; rm -rf epdfview.png )
@@ -30,3 +30,6 @@ echo "Enjoy The Theme"
 ( cd usr/share/icons/Faenza/categories/48 ; ln -sf /usr/share/icons/Faenza/categories//preferences-desktop.png multimedia-volume-control.png )
 ( cd usr/share/icons/Faenza/categories/scalable ; rm -rf multimedia-volume-control.svg )
 ( cd usr/share/icons/Faenza/categories/scalable ; ln -sf /usr/share/icons/Faenza/categories/scalable/preferences-desktop.svg multimedia-volume-control.svg )
+
+( cd boot/bitmap ; rm -rf boot.bmp )
+( cd boot/bitmap ; ln -sf /boot/bitmap/VL-Seven.bmp boot.bmp )
